<?php
/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */

namespace App\Http\Controllers\Admin\Settings;

use App\Jobshunt\Models\User;
use App\Http\Controllers\Controller;
use App\Jobshunt\Models\Post;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\DB;

class UpdateController extends Controller
{
    /**
     * @param Request $request
     * @return mixed
     */
    public function postSiteDetails(Request $request)
    {
        if ($request->hasFile('fav_icon')) {
            $request->file('fav_icon')->move(public_path(), 'favicon.ico');
        }
        DB::table('sitesettings')->where('option', 'siteName')->update(['value' => $request->get('sitename')]);
        DB::table('sitesettings')->where('option', 'description')->update(['value' => $request->get('description')]);
        DB::table('sitesettings')->where('option', 'privacy')->update(['value' => $request->get('privacy')]);
        DB::table('sitesettings')->where('option', 'faq')->update(['value' => $request->get('faq')]);
        DB::table('sitesettings')->where('option', 'tos')->update(['value' => $request->get('tos')]);
        DB::table('sitesettings')->where('option', 'about')->update(['value' => $request->get('about')]);

        Artisan::call('cache:clear');

        return redirect()->back()->with('flashSuccess', 'Site Details Updated');
    }

    /**
     * @param Request $request
     */
    public function postCurrencyDetails(Request $request)
    {
        $this->validate($request, [
            'currency'     => 'required',
            'amount'       => 'required|integer',
            'numberOfDays' => 'required|integer',
        ]);

        DB::table('sitesettings')->where('option', 'currency')->update(['value' => $request->get('currency')]);
        DB::table('sitesettings')->where('option', 'amount')->update(['value' => $request->get('amount')]);
        DB::table('sitesettings')->where('option', 'numberOfDays')->update(['value' => $request->get('numberOfDays')]);
        if ($request->get('isFree')) {
            DB::table('sitesettings')->where('option', 'isFree')->update(['value' => 1]);
        } else {
            DB::table('sitesettings')->where('option', 'isFree')->update(['value' => 0]);
        }

        Artisan::call('cache:clear');

        return redirect()->back()->with('flashSuccess', 'Currency/Charges Details Updated');
    }

    /**
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function postLimitSettings(Request $request)
    {
        $this->validate($request, [
            'perPage'   => 'required',
            'tagsLimit' => 'required',
        ]);

        DB::table('sitesettings')->where('option', 'perPage')->update(['value' => (int)$request->get('perPage')]);
        DB::table('sitesettings')->where('option', 'tagsLimit')->update(['value' => (int)$request->get('tagsLimit')]);

        Artisan::call('cache:clear');

        return redirect()->back()->with('flashSuccess', 'Your limits are now updated');
    }


    /**
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function postCacheSettings(Request $request)
    {
        if ($request->get('settings_cache')) {
            Artisan::call('cache:clear');
        }

        if ($request->get('template_cache')) {
            Artisan::call('view:clear');
        }
        if ($request->get('route_cache')) {
            Artisan::call('route:clear');
            Artisan::call('route:cache');
        }

        return redirect()->back()->with('flashSuccess', 'Cache is cleared now');
    }

    /**
     * @return mixed
     */
    public function updateSiteMap()
    {
        $sitemap = app()->make('sitemap');

        $posts = Post::orderBy('approved_at', 'desc')->get();
        foreach ($posts as $post) {
            $sitemap->add(route('posts.main', ['id' => $post->id, 'slug' => $post->slug]), $post->approved_at, '0.9');
        }
        $users = User::orderBy('confirmed_at', 'desc')->get();
        foreach ($users as $user) {
            $sitemap->add(route('users.profile', ['username' => $user->username]), $user->confirmed_at, '0.5');
        }
        $sitemap->store('xml', 'sitemap');

        return redirect()->route('admin')->with('flashSuccess', 'sitemap.xml is now updated');
    }
}
