<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Foundation\Auth\ResetsPasswords;
use Illuminate\Http\Request;
use Illuminate\Mail\Message;
use Illuminate\Support\Facades\Password;

class PasswordController extends Controller
{
    use ResetsPasswords;

    protected $redirectPath = '/';

    public function __construct()
    {
        $this->middleware('guest');
    }

    public function getEmail()
    {
        $title = t('Password Reset');

        return view('auth.password', compact('title'));
    }

    public function getReset($token = null)
    {
        if (is_null($token)) {
            throw new NotFoundHttpException;
        }
        $title = t('Password Reset');

        return view('auth.reset', compact('token', 'title'));
    }

    public function postEmail(Request $request)
    {
        $this->validate($request, ['email' => 'required|email','g-recaptcha-response' => 'required|recaptcha']);

        $response = Password::sendResetLink($request->only('email'), function (Message $message) {
            $message->subject($this->getEmailSubject());
        });

        switch ($response) {
            case Password::RESET_LINK_SENT:
                return redirect()->back()->with('flashSuccess', trans($response));

            case Password::INVALID_USER:
                return redirect()->back()->withErrors(['email' => trans($response)]);
        }
    }
}
