<?php

namespace App\Http\Controllers;

use App\Http\Requests\User\UpdateAvatar;
use App\Http\Requests\User\UpdatePassword;
use App\Http\Requests\User\UpdateSettings;
use App\Jobshunt\Helpers\ResizeHelper;
use App\Jobshunt\Repository\UsersRepositoryInterface;
use Illuminate\Http\Request;

/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */
class UserController extends Controller
{
    /**
     * @var UsersRepositoryInterface
     */
    private $user;

    /**
     * @param UsersRepositoryInterface $user
     */
    public function __construct(UsersRepositoryInterface $user)
    {
        $this->user = $user;
    }

    /**
     * @param Request $request
     * @return \BladeView|bool|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function index(Request $request)
    {
        $title = t('Users List');
        $users = $this->user->getAll($request);

        return view('users.list', compact('title', 'users'));
    }

    /**
     * @param $username
     * @return \BladeView|bool|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function show($username)
    {
        $user = $this->user->getByUsername($username);
        $posts = $this->user->getUserPosts($user);
        $title = $user->fullname . ' ' . t('Profile');

        return view('users.index', compact('title', 'user', 'posts'));
    }

    /**
     * @return \BladeView|bool|\Illuminate\View\View
     */
    public function getSettings()
    {
        $title = t('Settings');

        return view('users.settings', compact('title'));
    }

    /**
     * @param UpdateSettings $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function postSettings(UpdateSettings $request)
    {
        $this->user->updateSettings($request);

        return redirect()->back()->with('flashSuccess', t('Setting are now updated'));
    }

    /**
     * @param UpdateAvatar $request
     * @return mixed
     */
    public function postUpdateAvatar(UpdateAvatar $request)
    {
        $i = new ResizeHelper(auth()->user()->avatar, 'uploads/avatars');
        $i->delete();

        $i = new ResizeHelper($request->file('avatar'), 'uploads/avatars');
        list($name, $type) = $i->saveOriginal();

        $update = auth()->user();
        $update->avatar = sprintf('%s.%s', $name, $type);
        $update->save();

        return redirect()->back()->with('flashSuccess', t('Your avatar is now updated'));
    }


    /**
     * @return mixed
     */
    public function postChangePassword(UpdatePassword $request)
    {
        if (!$this->user->updatePassword($request)) {
            return redirect()->back()->with('flashError', t('Old password is not valid'));
        }

        return redirect()->back()->with('flashSuccess', t('Your password is updated'));
    }

    /**
     * @param Request $request
     * @return \BladeView|bool|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function getContact(Request $request)
    {
        $title = sprintf('%s %s', t('Contacting'), $request->route('username'));
        $user = $this->user->getByUsername($request->route('username'));
        if ($user->is_freelancer == false || auth()->user()->id === $user->id) {
            return redirect()->route('home')->with('flashError', t('You are not allowed'));
        }
        return view('users.contact', compact('title'));
    }

    /**
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function postContact(Request $request)
    {
        $this->validate($request, [
            'g-recaptcha-response' => ['required', 'recaptcha']
        ]);
        $this->user->sendContactEmail($request);

        return redirect()->route('users.profile', ['username' => $request->route('username')])->with('flashSuccess', t('Your message is sent to user by email'));
    }
}
