<?php

/*
|--------------------------------------------------------------------------
| Application Routes
|--------------------------------------------------------------------------
|
| Here is where you can register all of the routes for an application.
| It's a breeze. Simply tell Laravel the URIs it should respond to
| and give it the controller to call when that URI is requested.
|
*/
Route::get('/', ['as' => 'home', 'uses' => 'PostController@index']);
Route::get('users', ['as' => 'users.list', 'uses' => 'UserController@index']);
Route::get('users/{username}', ['as' => 'users.profile', 'uses' => 'UserController@show']);
Route::get('jobs', ['as' => 'posts.list', 'uses' => 'PostController@index']);
Route::get('rss', ['as' => 'rss', 'uses' => 'PostController@rss']);
Route::get('jobs/{id}-{slug}', ['as' => 'posts.main', 'uses' => 'PostController@show']);
Route::post('jobs/{id}-{slug}/apply', ['middleware' => 'csrf', 'as' => 'posts.apply', 'uses' => 'PostController@postApply']);
Route::get('tos', ['as' => 'tos', 'uses' => 'PolicyController@getTos']);
Route::get('privacy', ['as' => 'privacy', 'uses' => 'PolicyController@getPrivacy']);
Route::get('faq', ['as' => 'faq', 'uses' => 'PolicyController@getFaq']);
Route::get('about', ['as' => 'about', 'uses' => 'PolicyController@getAbout']);
Route::get('lang/{lang?}', 'PolicyController@switchLang');
Route::post('queue/receive', 'PolicyController@queue');

Route::group(['middleware' => 'guest'], function () {
    Route::get('login', ['as' => 'login', 'uses' => 'Auth\LoginController@getLogin']);
    Route::get('auth/{provider}', 'Auth\LoginController@getSocial');
    Route::get('auth/{provider}/callback', 'Auth\LoginController@getSocialCallback');
    Route::get('registration/{provider}', 'Auth\RegistrationController@getSocialRegister');
    Route::get('registration', ['as' => 'registration', 'uses' => 'Auth\RegistrationController@getIndex']);
    Route::get('registration/activate/{username}/{code}', 'Auth\RegistrationController@validateUser');
    Route::get('password/email', ['as' => 'password.reminder', 'uses' => 'Auth\PasswordController@getEmail']);
    Route::get('password/reset/{token}', 'Auth\PasswordController@getReset');
});


Route::group(['middleware' => 'csrf:guest'], function () {
    Route::post('login', 'Auth\LoginController@postLogin');
    Route::post('registration/{provider}', 'Auth\RegistrationController@postSocialRegister');
    Route::post('password/email', 'Auth\PasswordController@postEmail');
    Route::post('password/reset/{token}', 'Auth\PasswordController@postReset');
    Route::post('registration', 'Auth\RegistrationController@postIndex');
});

Route::group(['middleware' => 'auth'], function () {
    Route::get('jobs/create', ['as' => 'posts.create', 'uses' => 'PostController@create']);
    Route::get('jobs/create/paypalSuccess', ['as' => 'posts.create.paypalSuccess', 'uses' => 'PostController@paypalSuccess']);
    Route::get('users/{username}/settings', ['as' => 'users.settings', 'uses' => 'UserController@getSettings']);
    Route::get('users/{username}/contact', ['as' => 'users.contact', 'uses' => 'UserController@getContact']);
    Route::get('jobs/{id}-{slug}/edit', ['as' => 'posts.edit', 'uses' => 'PostController@getEdit']);
    Route::get('logout', ['as' => 'logout', 'uses' => 'Auth\LoginController@getLogout']);
});

Route::group(['middleware' => 'csrf:auth'], function () {
    Route::post('jobs/create', ['as' => 'posts.create', 'uses' => 'PostController@store']);
    Route::post('users/{username}/settings', ['as' => 'users.settings', 'uses' => 'UserController@postSettings']);
    Route::post('settings/updateavatar', 'UserController@postUpdateAvatar');
    Route::post('settings/changepassword', 'UserController@postChangePassword');
    Route::post('users/{username}/contact', ['as' => 'users.contact', 'uses' => 'UserController@postContact']);
    Route::post('jobs/{id}-{slug}/edit', ['as' => 'posts.edit', 'uses' => 'PostController@postEdit']);
});


Route::group(['middleware' => 'admin', 'namespace' => 'Admin'], function () {
    Route::get('admin', ['as' => 'admin', 'uses' => 'IndexController@getIndex']);

    // User
    Route::get('admin/users', ['as' => 'admin.users', 'uses' => 'User\UserController@getIndex']);
    Route::get('admin/users/data', ['as' => 'admin.users.data', 'uses' => 'User\UserController@getData']);
    Route::get('admin/users/{id}/edit', ['as' => 'admin.users.edit', 'uses' => 'User\UpdateController@getEdit']);
    Route::get('admin/users/add', ['as' => 'admin.users.add', 'uses' => 'User\UserController@getAddUser']);
    Route::post('admin/users/add', ['as' => 'admin.users.add', 'uses' => 'User\UpdateController@postAddUser']);
    Route::post('admin/users/{id}/edit', ['as' => 'admin.users.edit', 'uses' => 'User\UpdateController@postEdit']);
    Route::post('admin/users/approve', ['as' => 'admin.users.approve', 'uses' => 'User\UpdateController@postApprove']);

    // Posts Manger
    Route::get('admin/posts', ['as' => 'admin.posts', 'uses' => 'Post\PostController@getIndex']);
    Route::get('admin/posts/data', ['as' => 'admin.posts.data', 'uses' => 'Post\PostController@getData']);
    Route::get('admin/posts/{id}/edit', ['as' => 'admin.posts.edit', 'uses' => 'Post\UpdateController@getEdit']);
    Route::post('admin/posts/{id}/edit', ['as' => 'admin.posts.edit', 'uses' => 'Post\UpdateController@postEdit']);
    Route::post('admin/posts/reapprove', ['as' => 'admin.posts.approve', 'uses' => 'Post\UpdateController@postReApprove']);

    // Category
    Route::get('admin/categories', ['as' => 'admin.categories', 'uses' => 'Category\CategoryController@index']);
    Route::post('admin/categories', 'Category\CategoryController@create');
    Route::post('admin/categories/reorder', 'Category\CategoryController@reorder');
    Route::post('admin/categories/update', 'Category\CategoryController@update');

    // Category
    Route::get('admin/posttype', ['as' => 'admin.posttype', 'uses' => 'Posttype\PosttypeController@index']);
    Route::post('admin/posttype', 'Posttype\PosttypeController@create');
    Route::post('admin/posttype/reorder', 'Posttype\PosttypeController@reorder');
    Route::post('admin/posttype/update', 'Posttype\PosttypeController@update');

    // Site Settings
    Route::get('admin/settings/details', ['as' => 'admin.settings.details', 'uses' => 'Settings\SettingsController@getSiteDetails']);
    Route::post('admin/settings/details', ['as' => 'admin.settings.details', 'uses' => 'Settings\UpdateController@postSiteDetails']);
    Route::get('admin/settings/currency', ['as' => 'admin.settings.currency', 'uses' => 'Settings\SettingsController@getCurrencyDetails']);
    Route::post('admin/settings/currency', ['as' => 'admin.settings.currency', 'uses' => 'Settings\UpdateController@postCurrencyDetails']);
    Route::get('admin/settings/limits', ['as' => 'admin.settings.limits', 'uses' => 'Settings\SettingsController@getLimitSettings']);
    Route::post('admin/settings/limits', ['as' => 'admin.settings.limits', 'uses' => 'Settings\UpdateController@postLimitSettings']);
    Route::get('admin/settings/cache', ['as' => 'admin.settings.cache', 'uses' => 'Settings\SettingsController@getCacheSettings']);
    Route::post('admin/settings/cache', ['as' => 'admin.settings.cache', 'uses' => 'Settings\UpdateController@postCacheSettings']);
    Route::get('admin/settings/sitemap', ['as' => 'admin.settings.sitemap', 'uses' => 'Settings\UpdateController@updateSiteMap']);
});
