<?php
/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */
namespace App\Jobshunt\Mailers;

use App\Jobshunt\Models\User;
use Illuminate\Http\Request;

class UserMailer extends Mailer
{

    /**
     * @param User $user
     * @param $activationCode
     */
    public function activation(User $user, $activationCode)
    {
        $subject = "Welcome";
        $view = 'emails.registration.confirmation';
        $data = [
            'fullname'       => $user->fullname,
            'username'       => $user->username,
            'activationcode' => $activationCode
        ];

        return $this->sendTo($user, $subject, $view, $data);
    }

    /**
     * @param User $to
     * @param User $from
     */
    public function contactEmail(User $to, User $from, $description)
    {
        $subject = $from->fullname . '-' . siteSettings('siteName');
        $view = 'emails.usermailer.contact';
        $data = [
            'senderEmail'       => $from->email,
            'senderFullname'    => ucfirst($from->fullname),
            'senderProfileLink' => route('users.profile', ['username' => $from->username]),
            'description'       => $description,
        ];

        return $this->sendTo($to, $subject, $view, $data);
    }

    /**
     * @param User $to
     * @param User $from
     */
    public function applyEmail(User $to, Request $request, $post, $resume)
    {
        $subject = $request->get('name') . '-' . siteSettings('siteName');
        $view = 'emails.usermailer.apply';
        $data = [
            'senderEmail'    => $request->get('email'),
            'senderFullname' => ucfirst($request->get('name')),
            'senderPhone'    => $request->get('phone'),
            'attachment'     => $resume,
            'appliedFor'     => $post->title,
            'appliedForLink' => route('posts.main', ['id' => $request->route('id'), $request->route('slug')]),
        ];

        return $this->sendTo($to, $subject, $view, $data);
    }
}