<?php
namespace App\Jobshunt\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */
class Post extends Model
{
    use SoftDeletes;

    /**
     * @var string
     */
    protected $table = 'posts';

    /**
     * @var bool
     */
    protected $softDelete = true;

    /**
     * @var array
     */
    protected $dates = ['created_at', 'deleted_at', 'approved_at', 'expire_at'];

    /**
     * @return mixed
     */
    public static function scopeApproved()
    {
        return static::where('expire_at', '>=', Carbon::now());
    }

    /**
     * @param $value
     * @return string
     */
    public function getTitleAttribute($value)
    {
        return ucfirst($value);
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function user()
    {
        return $this->belongsTo(User::class);
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function type()
    {
        return $this->belongsTo(PostType::class, 'post_type_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function category()
    {
        return $this->belongsTo(Category::class, 'category_id');
    }
}